==> jimfs_1.1.orig.tar.gz: jimfs-1.1/jimfs/src/main/java/com/google/common/jimfs/DowngradedDirectoryStream.java <==
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.common.jimfs;

import static com.google.common.base.Preconditions.checkNotNull;

import java.io.IOException;
import java.nio.file.DirectoryStream;
import java.nio.file.Path;
import java.nio.file.SecureDirectoryStream;
import java.util.Iterator;

/**
 * A thin wrapper around a {@link SecureDirectoryStream} that exists only to implement
 * {@link DirectoryStream} and NOT implement {@link SecureDirectoryStream}.
 *
 * @author Colin Decker
 */
final class DowngradedDirectoryStream implements DirectoryStream<Path> {

  private final SecureDirectoryStream<Path> secureDirectoryStream;

  DowngradedDirectoryStream(SecureDirectoryStream<Path> secureDirectoryStream) {
    this.secureDirectoryStream = checkNotNull(secureDirectoryStream);
  }

  @Override
  public Iterator<Path> iterator() {
    return secureDirectoryStream.iterator();
  }

  @Override
  public void close() throws IOException {
    secureDirectoryStream.close();
  }
}

==> jimfs-1.3.1.tar.gz: jimfs-1.3.1/jimfs/src/main/java/com/google/common/jimfs/DowngradedDirectoryStream.java <==
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.common.jimfs;

import static com.google.common.base.Preconditions.checkNotNull;

import java.io.IOException;
import java.nio.file.DirectoryStream;
import java.nio.file.Path;
import java.nio.file.SecureDirectoryStream;
import java.util.Iterator;

/**
 * A thin wrapper around a {@link SecureDirectoryStream} that exists only to implement {@link
 * DirectoryStream} and NOT implement {@link SecureDirectoryStream}.
 *
 * @author Colin Decker
 */
final class DowngradedDirectoryStream implements DirectoryStream<Path> {

  private final SecureDirectoryStream<Path> secureDirectoryStream;

  DowngradedDirectoryStream(SecureDirectoryStream<Path> secureDirectoryStream) {
    this.secureDirectoryStream = checkNotNull(secureDirectoryStream);
  }

  @Override
  public Iterator<Path> iterator() {
    return secureDirectoryStream.iterator();
  }

  @Override
  public void close() throws IOException {
    secureDirectoryStream.close();
  }
}
